@@ -80,6 +80,39 @@ glibtop_get_cpu_l (glibtop *server, glibtop_cpu *buf)
 					  &server->required.cpu);
 }
 
+void
+glibtop_get_disk_l (glibtop *server, glibtop_disk *buf)
+{
+	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_DISK), 0);
+
+	/* If neccessary, we ask the server for the requested
+	 * feature. If not, we call the sysdeps function. */
+
+	if ((server->flags & _GLIBTOP_INIT_STATE_SERVER) &&
+	    (server->features & (1 << GLIBTOP_SYSDEPS_DISK)))
+	{
+		const void *send_ptr = NULL;
+		const size_t send_size = 0;
+
+		glibtop_call_l (server, GLIBTOP_CMND_DISK,
+				send_size, send_ptr,
+				sizeof (glibtop_disk), buf);
+	} else {
+#if (!GLIBTOP_SUID_DISK)
+		glibtop_get_disk_s (server, buf);
+#else
+		errno = ENOSYS;
+		glibtop_error_io_r (server, "glibtop_get_disk");
+#endif
+	}
+
+	/* Make sure that all required fields are present. */
+
+	if (buf->flags & server->required.disk)
+		_glibtop_missing_feature (server, "disk", buf->flags,
+					  &server->required.disk);
+}
+
 void
 glibtop_get_mem_l (glibtop *server, glibtop_mem *buf)
 {
