@@ -27,6 +27,7 @@
 
 const unsigned long glibtop_server_features =
 GLIBTOP_SUID_CPU +
+GLIBTOP_SUID_DISK +
 GLIBTOP_SUID_MEM +
 GLIBTOP_SUID_SWAP +
 GLIBTOP_SUID_UPTIME +
@@ -44,6 +45,7 @@ GLIBTOP_SUID_PROC_KERNEL +
 GLIBTOP_SUID_PROC_SEGMENT +
 GLIBTOP_SUID_PROC_ARGS +
 GLIBTOP_SUID_PROC_MAP +
+GLIBTOP_SUID_PROC_OPEN_FILES +
 GLIBTOP_SUID_NETLOAD +
 GLIBTOP_SUID_NETLIST +
 GLIBTOP_SUID_PROC_WD +
@@ -55,6 +57,9 @@ const _glibtop_init_func_t _glibtop_init_hook_s [] = {
 #if !GLIBTOP_SUID_CPU
 	_glibtop_init_cpu_s,
 #endif
+#if !GLIBTOP_SUID_DISK
+	_glibtop_init_disk_s,
+#endif
 #if !GLIBTOP_SUID_MEM
 	_glibtop_init_mem_s,
 #endif
@@ -123,6 +128,9 @@ const _glibtop_init_func_t _glibtop_init_hook_s [] = {
 #endif
 #if !GLIBTOP_SUID_PROC_IO
 	_glibtop_init_proc_io_s,
+#endif
+#if !GLIBTOP_SUID_PROC_OPEN_FILES
+	_glibtop_init_proc_open_files_s,
 #endif
 	NULL
 };
@@ -131,6 +139,9 @@ const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_CPU
 	_glibtop_init_cpu_p,
 #endif
+#if GLIBTOP_SUID_DISK
+	_glibtop_init_disk_p,
+#endif
 #if GLIBTOP_SUID_MEM
 	_glibtop_init_mem_p,
 #endif
@@ -199,6 +210,9 @@ const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #endif
 #if GLIBTOP_SUID_PROC_IO
 	_glibtop_init_proc_io_p,
+#endif
+#if GLIBTOP_SUID_PROC_OPEN_FILES
+	_glibtop_init_proc_open_files_p,
 #endif
 	NULL
 };
