@@ -1,5 +1,3 @@
-/* $OpenBSD: glibtop_server.h,v 1.2 2011/05/23 19:35:53 jasper Exp $	*/
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -17,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GLIBTOP_SERVER_H__
@@ -26,11 +24,7 @@
 
 G_BEGIN_DECLS
 
-#define GLIBTOP_SUID_CPU		(1 << GLIBTOP_SYSDEPS_CPU)
-#define GLIBTOP_SUID_MEM		(1 << GLIBTOP_SYSDEPS_MEM)
 #define GLIBTOP_SUID_SWAP		(1 << GLIBTOP_SYSDEPS_SWAP)
-#define GLIBTOP_SUID_UPTIME		(1 << GLIBTOP_SYSDEPS_UPTIME)
-#define GLIBTOP_SUID_LOADAVG		(1 << GLIBTOP_SYSDEPS_LOADAVG)
 #define GLIBTOP_SUID_SHM_LIMITS		(1 << GLIBTOP_SYSDEPS_SHM_LIMITS)
 #define GLIBTOP_SUID_MSG_LIMITS		(1 << GLIBTOP_SYSDEPS_MSG_LIMITS)
 #define GLIBTOP_SUID_SEM_LIMITS		(1 << GLIBTOP_SYSDEPS_SEM_LIMITS)
@@ -45,10 +39,17 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_PROC_ARGS		(1 << GLIBTOP_SYSDEPS_PROC_ARGS)
 #define GLIBTOP_SUID_PROC_MAP		(1 << GLIBTOP_SYSDEPS_PROC_MAP)
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
-#define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PPP		(1 << GLIBTOP_SYSDEPS_PPP)
+#define GLIBTOP_SUID_CPU		0
+#define GLIBTOP_SUID_DISK		0
+#define GLIBTOP_SUID_MEM		0
+#define GLIBTOP_SUID_UPTIME		0
+#define GLIBTOP_SUID_LOADAVG		0
+#define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PROC_WD		0
 #define GLIBTOP_SUID_PROC_AFFINITY	0
+#define GLIBTOP_SUID_PROC_IO		0
+#define GLIBTOP_SUID_PROC_OPEN_FILES	0
 
 G_END_DECLS
 
